<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Block\Adminhtml\Schedule\Edit;

use Neklo\Scheduler\Controller\Adminhtml\Schedule\Edit as EditCtrl;
use Neklo\Scheduler\Api\Data\ScheduleInterface;

class Form extends \Magento\Backend\Block\Widget\Form\Generic
{
    /**
     * @var \Neklo\Scheduler\Helper\Job
     */
    private $jobHelper;

    /**
     * @var \Neklo\Scheduler\Helper\Status
     */
    private $statusHelper;

    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Neklo\Scheduler\Helper\Job $jobHelper,
        \Neklo\Scheduler\Helper\Status $statusHelper,
        array $data = []
    ) {
        $this->jobHelper = $jobHelper;
        $this->statusHelper = $statusHelper;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('schedule_form');
        $this->setTitle(__('Scheduled Job Information'));
        $this->setAction('*/schedule/save');
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create(
            [
                'data' => [
                    'id'     => 'edit_form',
                    'action' => $this->getData('action'),
                    'method' => 'post',
                ]
            ]
        );

        $form->setHtmlIdPrefix('block_');

        $fieldset = $form->addFieldset(
            'base_fieldset',
            ['legend' => __('General Information'), 'class' => 'fieldset-wide']
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_ID,
            'hidden',
            ['name' => ScheduleInterface::SCHEDULE_ID]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_CODE,
            'select',
            [
                'name'   => ScheduleInterface::SCHEDULE_CODE,
                'label'  => __('Name'),
                'title'  => __('Name'),
                'values' => $this->jobHelper->getJobNameOptions(),
            ]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_SCHEDULED,
            'date',
            [
                'name'        => ScheduleInterface::SCHEDULE_SCHEDULED,
                'label'       => __('Time Scheduled'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled'    => false,
                'class'       => 'validate-date validate-date-range date-range-custom_theme-from',
            ]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_CREATED,
            'date',
            [
                'name'        => ScheduleInterface::SCHEDULE_CREATED,
                'label'       => __('Time Created'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled'    => false,
                'class'       => 'validate-date validate-date-range date-range-custom_theme-from',
            ]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_EXECUTED,
            'date',
            [
                'name'        => ScheduleInterface::SCHEDULE_EXECUTED,
                'label'       => __('Time Executed'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled'    => false,
                'class'       => 'validate-date validate-date-range date-range-custom_theme-from',
            ]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_FINISH,
            'date',
            [
                'name'        => ScheduleInterface::SCHEDULE_FINISH,
                'label'       => __('Time Finished'),
                'date_format' => 'yyyy-MM-dd',
                'time_format' => 'hh:mm:ss',
                'disabled'    => false,
                'class'       => 'validate-date validate-date-range date-range-custom_theme-from',
            ]
        );

        $fieldset->addField(
            ScheduleInterface::SCHEDULE_STATUS,
            'select',
            [
                'name'     => ScheduleInterface::SCHEDULE_STATUS,
                'label'    => __('Status'),
                'disabled' => false,
                'values'   => $this->statusHelper->getOptions(),
            ]
        );

        $model = $this->_coreRegistry->registry(EditCtrl::MODEL_REGISTRY);
        $form->setValues($model->getData());
        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}
