<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Controller\Adminhtml\Job;

use Neklo\Scheduler\Controller\Adminhtml;
use Neklo\Scheduler\Api\Data\JobInterface;
use Magento\Backend\Model\View\Result;

class Edit extends Adminhtml\Action
{
    const ADMIN_RESOURCE = 'Neklo_Scheduler::edit';

    /**
     * Redirect url
     */
    const REDIRECT_URL = '*/job/index';
    const MODEL_REGISTRY = 'edit_job';

    protected function _initAction(Result\Page $resultPage)
    {
        parent::_initAction($resultPage);
        $resultPage->setActiveMenu('Neklo_Scheduler::jobs');
    }

    public function execute()
    {
        $this->setupModel();

        $resultPage = $this->resultPageFactory->create();
        $this->_initAction($resultPage);
        $resultPage->addBreadcrumb(
            __('Edit Job'),
            __('Edit Job')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Cron Scheduler'));
        return $resultPage;
    }

    private function setupModel()
    {
        $id = $this->getRequest()->getParam(JobInterface::JOB_ID);
        $model = $this->_objectManager->create('Neklo\Scheduler\Model\Job');

        if ($id) {
            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addError(__('This job ID(%1) no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath(self::REDIRECT_URL);
            }
        }

        // 3. Set entered data if was error when we do save
        $data = $this->_objectManager->get('Magento\Backend\Model\Session')
            ->getFormData(true);
        if (!empty($data)) {
            $model->setData($data);
        }

        // 4. Register model to use later in blocks
        $this->coreRegistry->register(self::MODEL_REGISTRY, $model);

        return $this;
    }
}
